#
# spec file for package python-azure-data-tables
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%if 0%{?suse_version} >= 1500
%define skip_python2 1
%endif
Name:           python-azure-data-tables
Version:        12.5.0
Release:        1.4
Summary:        Microsoft Azure Azure Data Tables Client Library for Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/Azure/azure-sdk-for-python/tree/master/sdk/table/azure-table
Source:         https://files.pythonhosted.org/packages/source/a/azure-data-tables/azure-data-tables-%{version}.tar.gz
Source1:        LICENSE.txt
BuildRequires:  %{python_module azure-data-nspkg >= 1.0.0}
BuildRequires:  %{python_module azure-nspkg >= 3.0.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-azure-core < 2.0.0
Requires:       python-azure-core >= 1.29.4
Requires:       python-azure-data-nspkg >= 1.0.0
Requires:       python-azure-nspkg >= 3.0.0
Requires:       python-isodate < 1.0.0
Requires:       python-isodate >= 0.6.1
Requires:       python-yarl < 2.0
Requires:       python-yarl >= 1.0
Requires:       (python-typing_extensions >= 4.3.0 if python-base < 3.8)
%ifpython2
Requires:       python-enum34 >= 1.0.4
Requires:       python-futures
Requires:       python-typing
%endif
BuildArch:      noarch
%python_subpackages

%description
Azure Data Tables is a NoSQL data storage service that can be accessed from anywhere in the
world via authenticated calls using HTTP or HTTPS. Tables scales as needed to support the
amount of data inserted, and allow for the storing of data with non-complex accessing.
The Azure Data Tables client can be used to access Azure Storage or Cosmos accounts.

%prep
%setup -q -n azure-data-tables-%{version}

%build
install -m 644 %{SOURCE1} %{_builddir}/azure-data-tables-%{version}
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%{python_expand # delete common files
rm -rf %{buildroot}%{$python_sitelib}/azure/data/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/azure/data/__pycache__
rm -rf %{buildroot}%{$python_sitelib}/azure/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/azure/__pycache__
}

%files %{python_files}
%defattr(-,root,root,-)
%doc CHANGELOG.md README.md
%license LICENSE
%{python_sitelib}/azure/data/tables
%{python_sitelib}/azure_data_tables-*.egg-info

%changelog
* Thu Jan 11 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.5.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Fri Sep 15 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.4.4
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Remove unzip package from BuildRequires
- Switch source archive format to TAR.GZ
- Update Requires from setup.py
* Thu Jun 15 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.4.3
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Wed Feb  8 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.4.2
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Wed Oct 12 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.4.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Wed May 11 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.4.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Fri Mar 11 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.3.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Rename LICENSE.txt to LICENSE in %%files section
- Update Requires from setup.py
* Thu Nov 11 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.2.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Thu Jul 22 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.1.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Remove temporary version override
* Thu Jul  1 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Override upstream version with 12.0.0.0 to ensure
  proper upgrade from previous version 12.0.0b7
* Tue Jun  8 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.0.0b7
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Tue May  4 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.0.0b6
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Wed Mar 17 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.0.0b5
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Wed Feb 24 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.0.0b4
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Thu Nov 26 2020 Robert Schweikert <rjschwei@suse.com>
- Only build Python3 flavors for distributions 15 and greater
* Fri Nov 20 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.0.0b3
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Mon Oct 12 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 12.0.0b2
